#!/bin/bash
#
# Build the Booke. First assemble the book LaTeX, then build it
# into a PDF.
#
# All EPS and PDF tune graphics must be present already. Run
# makeGraphics.sh to make these.
#

# Restore titles like 'Exploding Potato, The' to the
# expected 'The Exploding Potato'.
fixtitle()
{
    retval=`echo "$1" | sed -e "s/\(.*\), *\(.*\)/\2 \1/"`
}

if [ $# != 1 ]; then
    echo "Usage: makeBookeA4.sh <book dir name>"
    exit 1
fi

dir=`pwd`

booke=$dir/$1
builddir=$dir/build
graphicsdir=$dir/graphics/$1
output=dottesA4.tex
outputxdv=${output/%.tex/.xdv}
outputpdf=${output/%.tex/.pdf}

mkdir -p $builddir

cp buildno.txt $builddir
cp buzzard.eps $builddir
if [ -r $booke/title.txt ]; then
    cp $booke/title.txt $builddir
else
    touch $builddir/title.txt
fi
if [ -r $booke/subtitle.txt ]; then
    cp $booke/subtitle.txt $builddir
else
    touch $builddir/subtitle.txt
fi
if [ -r $booke/intro.txt ]; then
    cp $booke/intro.txt $builddir
else
    touch $builddir/intro.txt
fi
cp dottes.tex.a4header $builddir/$output
cat dottes.tex.intro >> $builddir/$output

# Now, for each tune, make the tune graphic and add it, inside a
# centre section, so the document. Then add a TOC entry.
find $booke -name "*.abc" | sort |
    while read filename
    do
        name=`basename $filename .abc`
        title=`$dir/abcfield.py --field T --latex $filename`
        fixtitle "$title"
        title=$retval

        echo -E "\begin{figure}[H]" >> $builddir/$output
        echo -E "\phantomsection" >> $builddir/$output
        echo -E "{\centering \hypertarget{$name}{\includegraphics[width=\textwidth,keepaspectratio]{$graphicsdir/$name}}}" >> $builddir/$output
        echo -E "\addcontentsline{toc}{subsection}{$title}" >> $builddir/$output

        changefile=`$dir/abcfield.py --field N $filename | grep "Change:" | sed -e "s/Change: *//"`
        changetitle=""
        if [ -n "$changefile" ]; then
            changetitle=`$dir/abcfield.py --field T --latex $booke/$changefile`
            fixtitle "$changetitle"
            changetitle=$retval
            changename=`basename $changefile .abc`
            echo -E "Change: \hyperlink{$changename}{$changetitle}" >> $builddir/$output
        fi
        echo -E "\end{figure}" >> $builddir/$output
    done

cat dottes.tex.firstlines >> $builddir/$output

find $booke -name "*.abc" | sort |
    while read filename
    do
        name=`basename $filename .abc`
        title=`$dir/abcfield.py --field T --latex $filename`
        fixtitle "$title"
        title=$retval
        echo -E "\hyperlink{$name}{$title} & \raisebox{-.25\height}{\includegraphics[width=0.6\textwidth]{$graphicsdir/firstline-$name}} \\\\" >> $builddir/$output
    done

cat dottes.tex.footer >> $builddir/$output

cd $builddir

xelatex $output
xelatex $output
xelatex $output

mv $outputpdf $dir/$1-A4.pdf

cd $dir
